# nleis.py

`nleis.py` is designed as a toolbox that enables nonlinear impedance analysis for impedance.py. Key features include nonlinear ECMs and simultaneous analysis of EIS and 2nd-NLEIS. This repo will contains most recent version of `nleis.py`. As of today `nleis.py` supports the latest version of `impedance.py 1.7.1`.

### Installation

The `nleis.py` is avaliable in a standalone version now. You can install it directly with pip.

```bash
pip install nleis
```

See [Getting started with nleis.py](https://nleispy.readthedocs.io/en/latest/getting-started.html) for instructions on how to get most of this toolbox.

In the near future, you will be able to access all the funcationality for `nleis.py` from `impedance.py`.

#### Dependencies

`nleis.py` requires the same dependencies as `impedance.py` puls the latest version of `impedance.py`:

-   Python (>=3.8)
-   SciPy (>=1.0)
-   NumPy (>=1.14)
-   Matplotlib (>=3.0)
-   Altair (>=3.0)
-   impedance(>=1.7.1)
-   pandas (>= 2.0.2)


#### Examples and Documentation

The detailed documentation can be found at [nleispy.readthedocs.io](https://nleispy.readthedocs.io/en/latest).


### Credits
----------------------------------------------------------------

This work adopted and built the `nleis.py` based on [impedance.py](https://github.com/ECSHackWeek/impedance.py) (Murbach, M., Gerwe, B., Dawson-Elli, N., & Tsui, L. (2020). impedance.py: A Python package for electrochemical impedance analysis. Journal of Open Source Software, 5. https://doi.org/10.21105/joss.02349)

----------------------------------------------------------------
### Contributors :battery:

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/yuefan98"><img src="https://avatars.githubusercontent.com/u/97193085?v=4?s=100" width="100px;" alt="Yuefan Ji"/><br /><sub><b>Yuefan Ji</b></sub></a><br /><a href="#design-yuefan98" title="Design">🎨</a> <a href="https://github.com/yuefan98/nleis.py/commits?author=yuefan98" title="Code">💻</a> <a href="https://github.com/yuefan98/nleis.py/commits?author=yuefan98" title="Documentation">📖</a> <a href="https://github.com/yuefan98/nleis.py/commits?author=yuefan98" title="Tests">⚠️</a> <a href="https://github.com/yuefan98/nleis.py/pulls?q=is%3Apr+reviewed-by%3Ayuefan98" title="Reviewed Pull Requests">👀</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://mattmurbach.com"><img src="https://avatars.githubusercontent.com/u/9369020?v=4?s=100" width="100px;" alt="Matt Murbach"/><br /><sub><b>Matt Murbach</b></sub></a><br /><a href="https://github.com/yuefan98/nleis.py/commits?author=mdmurbach" title="Code">💻</a> <a href="https://github.com/yuefan98/nleis.py/pulls?q=is%3Apr+reviewed-by%3Amdmurbach" title="Reviewed Pull Requests">👀</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/dt-schwartz"><img src="https://avatars.githubusercontent.com/u/32350188?v=4?s=100" width="100px;" alt="Dan Schwartz"/><br /><sub><b>Dan Schwartz</b></sub></a><br /><a href="https://github.com/yuefan98/nleis.py/commits?author=dt-schwartz" title="Documentation">📖</a> <a href="https://github.com/yuefan98/nleis.py/pulls?q=is%3Apr+reviewed-by%3Adt-schwartz" title="Reviewed Pull Requests">👀</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->